#
# spec file for package golang-github-prometheus-node_exporter
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2017 Silvio Moioli <moio@suse.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{go_nostrip}

Name:           golang-github-prometheus-node_exporter
Version:        1.3.0
Release:        150100.3.18.1
Summary:        Prometheus exporter for machine metrics
License:        Apache-2.0
Group:          System/Management
URL:            https://prometheus.io/
Source:         node_exporter-%{version}.tar.gz
# Generated after applying 0001-Update-prometheus-client-to-1.11.1.patch
Source1:        vendor.tar.gz
Source2:        prometheus-node_exporter.service
Source4:        prometheus-node_exporter.sysconfig
# This patch has been applied before generating vendor tarball
Patch1:         0001-Update-prometheus-client-to-1.11.1.patch
BuildRequires:  fdupes
BuildRequires:  golang-github-prometheus-promu >= 0.12.0
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.14
%{?systemd_ordering}
Requires(post): %fillup_prereq
Requires(pre):  shadow
%{go_provides}
Provides:       node_exporter
Provides:       prometheus(node_exporter)
ExcludeArch:    s390
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%description
Prometheus exporter for hardware and OS metrics exposed by *NIX kernels, written in Go with pluggable metric collectors.

%prep
%autosetup -a1 -p1 -n node_exporter-%{version}

%build
%goprep github.com/prometheus/node_exporter
export BUILDFLAGS="-v -p 4 -x -buildmode=pie -mod=vendor"
GOPATH=%{_builddir}/go promu build

%install
%goinstall
install -D -m 0755 %{_builddir}/node_exporter-%{version}/node_exporter %{buildroot}/%{_bindir}/node_exporter
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/prometheus-node_exporter.service
install -D -m 0644 %{SOURCE4} %{buildroot}%{_fillupdir}/sysconfig.prometheus-node_exporter
%fdupes %{buildroot}

%check
%gotest github.com/prometheus/node_exporter -mod=vendor

%pre
%service_add_pre prometheus-node_exporter.service
getent group prometheus >/dev/null || %{_sbindir}/groupadd -r prometheus
getent passwd prometheus >/dev/null || %{_sbindir}/useradd -r -g prometheus -d %{_localstatedir}/lib/prometheus -M -s /sbin/nologin prometheus

%post
%service_add_post prometheus-node_exporter.service
%fillup_only -n prometheus-node_exporter

%preun
%service_del_preun prometheus-node_exporter.service

%postun
%service_del_postun prometheus-node_exporter.service

%files
%doc README.md
%license LICENSE
%{_bindir}/node_exporter
%{_unitdir}/prometheus-node_exporter.service
%{_fillupdir}/sysconfig.prometheus-node_exporter

%changelog
* Tue May 10 2022 jmassaguerpla@suse.com
- Exclude s390 arch.
* Wed Apr 13 2022 tdehler@suse.com
- Update spec file in order to make --version work (bsc#1196652)
* Wed Mar  9 2022 witold.bedyk@suse.com
- Update vendor tarball with prometheus/client_golang 1.11.1
  (bsc#1196338, jsc#SLE-24238, jsc#SLE-24239, jsc#SUMA-114,
  CVE-2022-21698)
  + Added 0001-Update-prometheus-client-to-1.11.1.patch
* Thu Nov 18 2021 michael@stroeder.com
- Update to 1.3.0
  * [CHANGE] Add path label to rapl collector #2146
  * [CHANGE] Exclude filesystems under /run/credentials #2157
  * [CHANGE] Add TCPTimeouts to netstat default filter #2189
  * [FEATURE] Add lnstat collector for metrics from /proc/net/stat/ #1771
  * [FEATURE] Add darwin powersupply collector #1777
  * [FEATURE] Add support for monitoring GPUs on Linux #1998
  * [FEATURE] Add Darwin thermal collector #2032
  * [FEATURE] Add os release collector #2094
  * [FEATURE] Add netdev.address-info collector #2105
  * [FEATURE] Add clocksource metrics to time collector #2197
  * [ENHANCEMENT] Support glob textfile collector directories #1985
  * [ENHANCEMENT] ethtool: Expose node_ethtool_info metric #2080
  * [ENHANCEMENT] Use include/exclude flags for ethtool filtering #2165
  * [ENHANCEMENT] Add flag to disable guest CPU metrics #2123
  * [ENHANCEMENT] Add DMI collector #2131
  * [ENHANCEMENT] Add threads metrics to processes collector #2164
  * [ENHANCMMENT] Reduce timer GC delays in the Linux filesystem collector #2169
  * [ENHANCMMENT] Add TCPTimeouts to netstat default filter #2189
  * [ENHANCMMENT] Use SysctlTimeval for boottime collector on BSD #2208
  * [BUGFIX] ethtool: Sanitize metric names #2093
  * [BUGFIX] Fix ethtool collector for multiple interfaces #2126
  * [BUGFIX] Fix possible panic on macOS #2133
  * [BUGFIX] Collect flag_info and bug_info only for one core #2156
  * [BUGFIX] Prevent duplicate ethtool metric names #2187
* Fri Oct  1 2021 dominik.gedon@suse.com
- Update to 1.2.2
  * Bug fixes
    Fix processes collector long int parsing #2112
- Update to 1.2.1
  * Removed
    Remove obsolete capture permission denied error patch
    capture-permission-denied-error-energy_uj.patch: Already included upstream
  * Bug fixes
    Fix zoneinfo parsing prometheus/procfs#386
    Fix nvme collector log noise #2091
    Fix rapl collector log noise #2092
- Update to 1.2.0
  * Changes
    Rename filesystem collector flags to match other collectors #2012
    Make node_exporter print usage to STDOUT #203
  * Features
    Add conntrack statistics metrics #1155
    Add ethtool stats collector #1832
    Add flag to ignore network speed if it is unknown #1989
    Add tapestats collector for Linux #2044
    Add nvme collector #2062
  * Enhancements
    Add ErrorLog plumbing to promhttp #1887
    Add more Infiniband counters #2019
    netclass: retrieve interface names and filter before parsing #2033
    Add time zone offset metric #2060
  * Bug fixes
    Handle errors from disabled PSI subsystem #1983
    Fix panic when using backwards compatible flags #2000
    Fix wrong value for OpenBSD memory buffer cache #2015
    Only initiate collectors once #2048
    Handle small backwards jumps in CPU idle #2067
* Thu Sep 23 2021 pseidensal@suse.com
- Apply patch to capture permission denied error for "energy_uj" file (bsc#1190535)
  * Adds patch capture-permission-denied-error-energy_uj.patch
    from https://github.com/prometheus/node_exporter/pull/2092
* Tue Mar  9 2021 witold.bedyk@suse.com
- Update to 1.1.2
  * Bug fixes
    + Handle errors from disabled PSI subsystem #1983
    + Sanitize strings from /sys/class/power_supply #1984
    + Silence missing netclass errors #1986
* Fri Feb 26 2021 witold.bedyk@suse.com
- Trim old specfile constructs
* Thu Feb 25 2021 witold.bedyk@suse.com
- Migrate to obs_scm
- Migrate to go_modules
- Update to 1.1.1
  * Bug fixes
    + Fix ineffassign issue #1957
    + Fix some noisy log lines #1962
- Update to 1.1.0
  * Changes
    + Improve filter flag names #1743
    + Add btrfs and powersupplyclass to list of exporters enabled by default #1897
  * Features
    + Add fibre channel collector #1786
    + Expose cpu bugs and flags as info metrics. #1788
    + Add network_route collector #1811
    + Add zoneinfo collector #1922
  * Enhancements
    + Add more InfiniBand counters #1694
    + Add flag to aggr ipvs metrics to avoid high cardinality metrics #1709
    + Adding backlog/current queue length to qdisc collector #1732
    + Include TCP OutRsts in netstat metrics #1733
    + Add pool size to entropy collector #1753
    + Remove CGO dependencies for OpenBSD amd64 #1774
    + bcache: add writeback_rate_debug stats #1658
    + Add check state for mdadm arrays via node_md_state metric #1810
    + Expose XFS inode statistics #1870
    + Expose zfs zpool state #1878
    + Added an ability to pass collector.supervisord.url via SUPERVISORD_URL environment variable #1947
  * Bug fixes
    + filesystem_freebsd: Fix label values #1728
    + Fix various procfs parsing errors #1735
    + Handle no data from powersupplyclass #1747
    + udp_queues_linux.go: change upd to udp in two error strings #1769
    + Fix node_scrape_collector_success behaviour #1816
    + Fix NodeRAIDDegraded to not use a string rule expressions #1827
    + Fix node_md_disks state label from fail to failed #1862
    + Handle EPERM for syscall in timex collector #1938
    + bcache: fix typo in a metric name #1943
    + Fix XFS read/write stats (https://github.com/prometheus/procfs/pull/343)
* Wed Feb 24 2021 witold.bedyk@suse.com
- Do not include sources (bsc#1151558)
- Remove rc symlink
* Fri Aug 21 2020 jcavalheiro@suse.com
- Update to 1.0.1
  * Changes to build specification
    + Modify spec: update golang version to 1.14
    + Remove update tarball script
    + Add _service file to allow for updates via `osc service disabledrun`
  * Bug fixes
    + [BUGFIX] filesystem_freebsd: Fix label values #1728
    + [BUGFIX] Update prometheus/procfs to fix log noise #1735
    + [BUGFIX] Fix build tags for collectors #1745
    + [BUGFIX] Handle no data from powersupplyclass #1747, #1749
- Update to 1.0.0
  * Bug fixes
    + [BUGFIX] Read /proc/net files with a single read syscall #1380
    + [BUGFIX] Renamed label state to name on node_systemd_service_restart_total. #1393
    + [BUGFIX] Fix netdev nil reference on Darwin #1414
    + [BUGFIX] Strip path.rootfs from mountpoint labels #1421
    + [BUGFIX] Fix seconds reported by schedstat #1426
    + [BUGFIX] Fix empty string in path.rootfs #1464
    + [BUGFIX] Fix typo in cpufreq metric names #1510
    + [BUGFIX] Read /proc/stat in one syscall #1538
    + [BUGFIX] Fix OpenBSD cache memory information #1542
    + [BUGFIX] Refactor textfile collector to avoid looping defer #1549
    + [BUGFIX] Fix network speed math #1580
    + [BUGFIX] collector/systemd: use regexp to extract systemd version #1647
    + [BUGFIX] Fix initialization in perf collector when using multiple CPUs #1665
    + [BUGFIX] Fix accidentally empty lines in meminfo_linux #1671
  * Several enhancements
    + See https://github.com/prometheus/node_exporter/releases/tag/v1.0.0
* Thu Feb 20 2020 michael@stroeder.com
- update to 1.0.0-rc.0
  Breaking changes
  * The netdev collector CLI argument --collector.netdev.ignored-devices
    was renamed to --collector.netdev.device-blacklist in order to conform
    with the systemd collector. #1279
  * The label named state on node_systemd_service_restart_total metrics was
    changed to name to better describe the metric. #1393
  * Refactoring of the mdadm collector changes several metrics
    node_md_disks_active is removed
    node_md_disks now has a state label for "fail", "spare", "active" disks.
    node_md_is_active is replaced by node_md_state with a state set of
    "active", "inactive", "recovering", "resync".
  * Additional label mountaddr added to NFS device metrics to distinguish
    mounts from the same URL, but different IP addresses. #1417
  * Metrics node_cpu_scaling_frequency_min_hrts and
    node_cpu_scaling_frequency_max_hrts of the cpufreq collector were
    renamed to node_cpu_scaling_frequency_min_hertz and
    node_cpu_scaling_frequency_max_hertz. #1510
  * Collectors that are enabled, but are unable to find data to collect,
    now return 0 for node_scrape_collector_success.
* Tue Sep 24 2019 dmaiocchi@suse.com
- Add missing sysconfig file in rpm  bsc#1151557
* Thu Aug 15 2019 michael@stroeder.com
- Update to 0.18.1
  0.18.1 / 2019-06-04
  Changes
  * [BUGFIX] Fix incorrect sysctl call in BSD meminfo collector, resulting in broken swap metrics on FreeBSD #1345
  * [BUGFIX] Fix rollover bug in mountstats collector #1364
  0.18.0 / 2019-05-09
  Breaking changes
  * Renamed interface label to device in netclass collector for consistency with
  * other network metrics #1224
  * The cpufreq metrics now separate the cpufreq and scaling data based on what the driver provides. #1248
  * The labels for the network_up metric have changed, see issue #1236
  * Bonding collector now uses mii_status instead of operstatus #1124
  * Several systemd metrics have been turned off by default to improve performance #1254
  * These include unit_tasks_current, unit_tasks_max, service_restart_total, and unit_start_time_seconds
  * The systemd collector blacklist now includes automount, device, mount, and slice units by default. #1255
  Changes
  * [CHANGE] Bonding state uses mii_status #1124
  * [CHANGE] Add a limit to the number of in-flight requests #1166
  * [CHANGE] Renamed interface label to device in netclass collector #1224
  * [CHANGE] Add separate cpufreq and scaling metrics #1248
  * [CHANGE] Several systemd metrics have been turned off by default to improve performance #1254
  * [CHANGE] Expand systemd collector blacklist #1255
  * [CHANGE] Split cpufreq metrics into a separate collector #1253
  * [FEATURE] Add a flag to disable exporter metrics #1148
  * [FEATURE] Add kstat-based Solaris metrics for boottime, cpu and zfs collectors #1197
  * [FEATURE] Add uname collector for FreeBSD #1239
  * [FEATURE] Add diskstats collector for OpenBSD #1250
  * [FEATURE] Add pressure collector exposing pressure stall information for Linux #1174
  * [FEATURE] Add perf exporter for Linux #1274
  * [ENHANCEMENT] Add Infiniband counters #1120
  * [ENHANCEMENT] Add TCPSynRetrans to netstat default filter #1143
  * [ENHANCEMENT] Move network_up labels into new metric network_info #1236
  * [ENHANCEMENT] Use 64-bit counters for Darwin netstat
  * [BUGFIX] Add fallback for missing /proc/1/mounts #1172
  * [BUGFIX] Fix node_textfile_mtime_seconds to work properly on symlinks #1326
* Fri Aug  2 2019 jan.fajerski@suse.com
- Add network-online (Wants and After) dependency to systemd unit bsc#1143913
* Tue Dec 11 2018 jan.fajerski@suse.com
- Update to 0.17.0
  + includes breaking changes
  + supvervisord collector reports start_time_seconds rather than uptime
  + The wifi collector is disabled by default due to suspected caching issues and goroutine leaks
  See https://github.com/prometheus/node_exporter/releases/tag/v0.17.0
  for full changelog
* Thu Nov 29 2018 jan.fajerski@suse.com
- Update to 0.16.0
  + includes breaking changes
  + several metrics renamed
  + split out cpu guest metrics
  See https://github.com/prometheus/node_exporter/releases/tag/v0.16.0
  for full changelog
* Sun Feb 18 2018 marix@marix.org
- Run tests during packaging
* Thu Jan 25 2018 kkaempf@suse.com
- Update to 0.15.2
  See https://github.com/prometheus/node_exporter/blob/master/CHANGELOG.md
- Provides node_exporter, prometheus(node_exporter)
* Thu Jul 27 2017 tserong@suse.com
- Add BuildRequires: fdupes
* Tue May  9 2017 tserong@suse.com
- Add systemd unit file
- Run as unprivileged "prometheus" user
* Wed Mar 29 2017 moio@suse.com
- Initial version
